# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class BidModifierSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[BidModifierSimulationPoint]: ...

    def __init__(self,
        *,
        points : typing___Optional[typing___Iterable[BidModifierSimulationPoint]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> BidModifierSimulationPointList: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"points"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"points",b"points"]) -> None: ...

class CpcBidSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[CpcBidSimulationPoint]: ...

    def __init__(self,
        *,
        points : typing___Optional[typing___Iterable[CpcBidSimulationPoint]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CpcBidSimulationPointList: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"points"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"points",b"points"]) -> None: ...

class CpvBidSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[CpvBidSimulationPoint]: ...

    def __init__(self,
        *,
        points : typing___Optional[typing___Iterable[CpvBidSimulationPoint]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CpvBidSimulationPointList: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"points"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"points",b"points"]) -> None: ...

class TargetCpaSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[TargetCpaSimulationPoint]: ...

    def __init__(self,
        *,
        points : typing___Optional[typing___Iterable[TargetCpaSimulationPoint]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TargetCpaSimulationPointList: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"points"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"points",b"points"]) -> None: ...

class BidModifierSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def bid_modifier(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def biddable_conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def biddable_conversions_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def top_slot_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def parent_biddable_conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def parent_biddable_conversions_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def parent_clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def parent_cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def parent_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def parent_top_slot_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        bid_modifier : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        biddable_conversions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        biddable_conversions_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        clicks : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        top_slot_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        parent_biddable_conversions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        parent_biddable_conversions_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        parent_clicks : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        parent_cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        parent_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        parent_top_slot_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> BidModifierSimulationPoint: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"bid_modifier",u"biddable_conversions",u"biddable_conversions_value",u"clicks",u"cost_micros",u"impressions",u"parent_biddable_conversions",u"parent_biddable_conversions_value",u"parent_clicks",u"parent_cost_micros",u"parent_impressions",u"parent_top_slot_impressions",u"top_slot_impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"bid_modifier",u"biddable_conversions",u"biddable_conversions_value",u"clicks",u"cost_micros",u"impressions",u"parent_biddable_conversions",u"parent_biddable_conversions_value",u"parent_clicks",u"parent_cost_micros",u"parent_impressions",u"parent_top_slot_impressions",u"top_slot_impressions"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"bid_modifier",b"bid_modifier",u"biddable_conversions",b"biddable_conversions",u"biddable_conversions_value",b"biddable_conversions_value",u"clicks",b"clicks",u"cost_micros",b"cost_micros",u"impressions",b"impressions",u"parent_biddable_conversions",b"parent_biddable_conversions",u"parent_biddable_conversions_value",b"parent_biddable_conversions_value",u"parent_clicks",b"parent_clicks",u"parent_cost_micros",b"parent_cost_micros",u"parent_impressions",b"parent_impressions",u"parent_top_slot_impressions",b"parent_top_slot_impressions",u"top_slot_impressions",b"top_slot_impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"bid_modifier",b"bid_modifier",u"biddable_conversions",b"biddable_conversions",u"biddable_conversions_value",b"biddable_conversions_value",u"clicks",b"clicks",u"cost_micros",b"cost_micros",u"impressions",b"impressions",u"parent_biddable_conversions",b"parent_biddable_conversions",u"parent_biddable_conversions_value",b"parent_biddable_conversions_value",u"parent_clicks",b"parent_clicks",u"parent_cost_micros",b"parent_cost_micros",u"parent_impressions",b"parent_impressions",u"parent_top_slot_impressions",b"parent_top_slot_impressions",u"top_slot_impressions",b"top_slot_impressions"]) -> None: ...

class CpcBidSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def biddable_conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def biddable_conversions_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def top_slot_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        cpc_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        biddable_conversions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        biddable_conversions_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        clicks : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        top_slot_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CpcBidSimulationPoint: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"biddable_conversions",u"biddable_conversions_value",u"clicks",u"cost_micros",u"cpc_bid_micros",u"impressions",u"top_slot_impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"biddable_conversions",u"biddable_conversions_value",u"clicks",u"cost_micros",u"cpc_bid_micros",u"impressions",u"top_slot_impressions"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"biddable_conversions",b"biddable_conversions",u"biddable_conversions_value",b"biddable_conversions_value",u"clicks",b"clicks",u"cost_micros",b"cost_micros",u"cpc_bid_micros",b"cpc_bid_micros",u"impressions",b"impressions",u"top_slot_impressions",b"top_slot_impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"biddable_conversions",b"biddable_conversions",u"biddable_conversions_value",b"biddable_conversions_value",u"clicks",b"clicks",u"cost_micros",b"cost_micros",u"cpc_bid_micros",b"cpc_bid_micros",u"impressions",b"impressions",u"top_slot_impressions",b"top_slot_impressions"]) -> None: ...

class CpvBidSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def cpv_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        cpv_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CpvBidSimulationPoint: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"cost_micros",u"cpv_bid_micros",u"impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cost_micros",u"cpv_bid_micros",u"impressions"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"cost_micros",b"cost_micros",u"cpv_bid_micros",b"cpv_bid_micros",u"impressions",b"impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cost_micros",b"cost_micros",u"cpv_bid_micros",b"cpv_bid_micros",u"impressions",b"impressions"]) -> None: ...

class TargetCpaSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def target_cpa_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def biddable_conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def biddable_conversions_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def top_slot_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        target_cpa_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        biddable_conversions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        biddable_conversions_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        clicks : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        top_slot_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TargetCpaSimulationPoint: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"biddable_conversions",u"biddable_conversions_value",u"clicks",u"cost_micros",u"impressions",u"target_cpa_micros",u"top_slot_impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"biddable_conversions",u"biddable_conversions_value",u"clicks",u"cost_micros",u"impressions",u"target_cpa_micros",u"top_slot_impressions"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"biddable_conversions",b"biddable_conversions",u"biddable_conversions_value",b"biddable_conversions_value",u"clicks",b"clicks",u"cost_micros",b"cost_micros",u"impressions",b"impressions",u"target_cpa_micros",b"target_cpa_micros",u"top_slot_impressions",b"top_slot_impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"biddable_conversions",b"biddable_conversions",u"biddable_conversions_value",b"biddable_conversions_value",u"clicks",b"clicks",u"cost_micros",b"cost_micros",u"impressions",b"impressions",u"target_cpa_micros",b"target_cpa_micros",u"top_slot_impressions",b"top_slot_impressions"]) -> None: ...
