# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class LocationPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class LocationPlaceholderField(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> LocationPlaceholderFieldEnum.LocationPlaceholderField: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[LocationPlaceholderFieldEnum.LocationPlaceholderField]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, LocationPlaceholderFieldEnum.LocationPlaceholderField]]: ...
        UNSPECIFIED = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 0)
        UNKNOWN = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 1)
        BUSINESS_NAME = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 2)
        ADDRESS_LINE_1 = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 3)
        ADDRESS_LINE_2 = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 4)
        CITY = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 5)
        PROVINCE = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 6)
        POSTAL_CODE = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 7)
        COUNTRY_CODE = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 8)
        PHONE_NUMBER = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 9)
    UNSPECIFIED = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 0)
    UNKNOWN = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 1)
    BUSINESS_NAME = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 2)
    ADDRESS_LINE_1 = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 3)
    ADDRESS_LINE_2 = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 4)
    CITY = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 5)
    PROVINCE = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 6)
    POSTAL_CODE = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 7)
    COUNTRY_CODE = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 8)
    PHONE_NUMBER = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 9)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> LocationPlaceholderFieldEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
