# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class FeedErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class FeedError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> FeedErrorEnum.FeedError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[FeedErrorEnum.FeedError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, FeedErrorEnum.FeedError]]: ...
        UNSPECIFIED = typing___cast(FeedErrorEnum.FeedError, 0)
        UNKNOWN = typing___cast(FeedErrorEnum.FeedError, 1)
        ATTRIBUTE_NAMES_NOT_UNIQUE = typing___cast(FeedErrorEnum.FeedError, 2)
        ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES = typing___cast(FeedErrorEnum.FeedError, 3)
        CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 4)
        CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 5)
        CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 6)
        CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE = typing___cast(FeedErrorEnum.FeedError, 7)
        FEED_REMOVED = typing___cast(FeedErrorEnum.FeedError, 8)
        INVALID_ORIGIN_VALUE = typing___cast(FeedErrorEnum.FeedError, 9)
        FEED_ORIGIN_IS_NOT_USER = typing___cast(FeedErrorEnum.FeedError, 10)
        INVALID_AUTH_TOKEN_FOR_EMAIL = typing___cast(FeedErrorEnum.FeedError, 11)
        INVALID_EMAIL = typing___cast(FeedErrorEnum.FeedError, 12)
        DUPLICATE_FEED_NAME = typing___cast(FeedErrorEnum.FeedError, 13)
        INVALID_FEED_NAME = typing___cast(FeedErrorEnum.FeedError, 14)
        MISSING_OAUTH_INFO = typing___cast(FeedErrorEnum.FeedError, 15)
        NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY = typing___cast(FeedErrorEnum.FeedError, 16)
        TOO_MANY_ATTRIBUTES = typing___cast(FeedErrorEnum.FeedError, 17)
        INVALID_BUSINESS_ACCOUNT = typing___cast(FeedErrorEnum.FeedError, 18)
        BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT = typing___cast(FeedErrorEnum.FeedError, 19)
        INVALID_AFFILIATE_CHAIN_ID = typing___cast(FeedErrorEnum.FeedError, 20)
        DUPLICATE_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 21)
    UNSPECIFIED = typing___cast(FeedErrorEnum.FeedError, 0)
    UNKNOWN = typing___cast(FeedErrorEnum.FeedError, 1)
    ATTRIBUTE_NAMES_NOT_UNIQUE = typing___cast(FeedErrorEnum.FeedError, 2)
    ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES = typing___cast(FeedErrorEnum.FeedError, 3)
    CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 4)
    CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 5)
    CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 6)
    CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE = typing___cast(FeedErrorEnum.FeedError, 7)
    FEED_REMOVED = typing___cast(FeedErrorEnum.FeedError, 8)
    INVALID_ORIGIN_VALUE = typing___cast(FeedErrorEnum.FeedError, 9)
    FEED_ORIGIN_IS_NOT_USER = typing___cast(FeedErrorEnum.FeedError, 10)
    INVALID_AUTH_TOKEN_FOR_EMAIL = typing___cast(FeedErrorEnum.FeedError, 11)
    INVALID_EMAIL = typing___cast(FeedErrorEnum.FeedError, 12)
    DUPLICATE_FEED_NAME = typing___cast(FeedErrorEnum.FeedError, 13)
    INVALID_FEED_NAME = typing___cast(FeedErrorEnum.FeedError, 14)
    MISSING_OAUTH_INFO = typing___cast(FeedErrorEnum.FeedError, 15)
    NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY = typing___cast(FeedErrorEnum.FeedError, 16)
    TOO_MANY_ATTRIBUTES = typing___cast(FeedErrorEnum.FeedError, 17)
    INVALID_BUSINESS_ACCOUNT = typing___cast(FeedErrorEnum.FeedError, 18)
    BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT = typing___cast(FeedErrorEnum.FeedError, 19)
    INVALID_AFFILIATE_CHAIN_ID = typing___cast(FeedErrorEnum.FeedError, 20)
    DUPLICATE_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 21)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
