# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class SearchTermMatchTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class SearchTermMatchType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> SearchTermMatchTypeEnum.SearchTermMatchType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[SearchTermMatchTypeEnum.SearchTermMatchType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, SearchTermMatchTypeEnum.SearchTermMatchType]]: ...
        UNSPECIFIED = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 0)
        UNKNOWN = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 1)
        BROAD = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 2)
        EXACT = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 3)
        PHRASE = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 4)
        NEAR_EXACT = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 5)
        NEAR_PHRASE = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 6)
    UNSPECIFIED = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 0)
    UNKNOWN = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 1)
    BROAD = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 2)
    EXACT = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 3)
    PHRASE = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 4)
    NEAR_EXACT = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 5)
    NEAR_PHRASE = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 6)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> SearchTermMatchTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
