# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class VanityPharmaTextEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class VanityPharmaText(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> VanityPharmaTextEnum.VanityPharmaText: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[VanityPharmaTextEnum.VanityPharmaText]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, VanityPharmaTextEnum.VanityPharmaText]]: ...
        UNSPECIFIED = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 0)
        UNKNOWN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 1)
        PRESCRIPTION_TREATMENT_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 2)
        PRESCRIPTION_TREATMENT_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 3)
        PRESCRIPTION_DEVICE_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 4)
        PRESCRIPTION_DEVICE_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 5)
        MEDICAL_DEVICE_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 6)
        MEDICAL_DEVICE_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 7)
        PREVENTATIVE_TREATMENT_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 8)
        PREVENTATIVE_TREATMENT_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 9)
        PRESCRIPTION_CONTRACEPTION_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 10)
        PRESCRIPTION_CONTRACEPTION_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 11)
        PRESCRIPTION_VACCINE_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 12)
        PRESCRIPTION_VACCINE_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 13)
    UNSPECIFIED = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 0)
    UNKNOWN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 1)
    PRESCRIPTION_TREATMENT_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 2)
    PRESCRIPTION_TREATMENT_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 3)
    PRESCRIPTION_DEVICE_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 4)
    PRESCRIPTION_DEVICE_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 5)
    MEDICAL_DEVICE_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 6)
    MEDICAL_DEVICE_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 7)
    PREVENTATIVE_TREATMENT_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 8)
    PREVENTATIVE_TREATMENT_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 9)
    PRESCRIPTION_CONTRACEPTION_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 10)
    PRESCRIPTION_CONTRACEPTION_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 11)
    PRESCRIPTION_VACCINE_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 12)
    PRESCRIPTION_VACCINE_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 13)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> VanityPharmaTextEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
