# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class AdTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AdType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> AdTypeEnum.AdType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[AdTypeEnum.AdType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, AdTypeEnum.AdType]]: ...
        UNSPECIFIED = typing___cast(AdTypeEnum.AdType, 0)
        UNKNOWN = typing___cast(AdTypeEnum.AdType, 1)
        TEXT_AD = typing___cast(AdTypeEnum.AdType, 2)
        EXPANDED_TEXT_AD = typing___cast(AdTypeEnum.AdType, 3)
        CALL_ONLY_AD = typing___cast(AdTypeEnum.AdType, 6)
        EXPANDED_DYNAMIC_SEARCH_AD = typing___cast(AdTypeEnum.AdType, 7)
        HOTEL_AD = typing___cast(AdTypeEnum.AdType, 8)
        SHOPPING_SMART_AD = typing___cast(AdTypeEnum.AdType, 9)
        SHOPPING_PRODUCT_AD = typing___cast(AdTypeEnum.AdType, 10)
        VIDEO_AD = typing___cast(AdTypeEnum.AdType, 12)
        GMAIL_AD = typing___cast(AdTypeEnum.AdType, 13)
        IMAGE_AD = typing___cast(AdTypeEnum.AdType, 14)
        RESPONSIVE_SEARCH_AD = typing___cast(AdTypeEnum.AdType, 15)
        LEGACY_RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdType, 16)
        APP_AD = typing___cast(AdTypeEnum.AdType, 17)
        LEGACY_APP_INSTALL_AD = typing___cast(AdTypeEnum.AdType, 18)
        RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdType, 19)
        HTML5_UPLOAD_AD = typing___cast(AdTypeEnum.AdType, 21)
        DYNAMIC_HTML5_AD = typing___cast(AdTypeEnum.AdType, 22)
        APP_ENGAGEMENT_AD = typing___cast(AdTypeEnum.AdType, 23)
        SHOPPING_COMPARISON_LISTING_AD = typing___cast(AdTypeEnum.AdType, 24)
    UNSPECIFIED = typing___cast(AdTypeEnum.AdType, 0)
    UNKNOWN = typing___cast(AdTypeEnum.AdType, 1)
    TEXT_AD = typing___cast(AdTypeEnum.AdType, 2)
    EXPANDED_TEXT_AD = typing___cast(AdTypeEnum.AdType, 3)
    CALL_ONLY_AD = typing___cast(AdTypeEnum.AdType, 6)
    EXPANDED_DYNAMIC_SEARCH_AD = typing___cast(AdTypeEnum.AdType, 7)
    HOTEL_AD = typing___cast(AdTypeEnum.AdType, 8)
    SHOPPING_SMART_AD = typing___cast(AdTypeEnum.AdType, 9)
    SHOPPING_PRODUCT_AD = typing___cast(AdTypeEnum.AdType, 10)
    VIDEO_AD = typing___cast(AdTypeEnum.AdType, 12)
    GMAIL_AD = typing___cast(AdTypeEnum.AdType, 13)
    IMAGE_AD = typing___cast(AdTypeEnum.AdType, 14)
    RESPONSIVE_SEARCH_AD = typing___cast(AdTypeEnum.AdType, 15)
    LEGACY_RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdType, 16)
    APP_AD = typing___cast(AdTypeEnum.AdType, 17)
    LEGACY_APP_INSTALL_AD = typing___cast(AdTypeEnum.AdType, 18)
    RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdType, 19)
    HTML5_UPLOAD_AD = typing___cast(AdTypeEnum.AdType, 21)
    DYNAMIC_HTML5_AD = typing___cast(AdTypeEnum.AdType, 22)
    APP_ENGAGEMENT_AD = typing___cast(AdTypeEnum.AdType, 23)
    SHOPPING_COMPARISON_LISTING_AD = typing___cast(AdTypeEnum.AdType, 24)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
