# Stubs for google.ads.google_ads.v2.proto.enums.customer_pay_per_conversion_eligibility_failure_reason_pb2_grpc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

