# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class OperationAccessDeniedErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class OperationAccessDeniedError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> OperationAccessDeniedErrorEnum.OperationAccessDeniedError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[OperationAccessDeniedErrorEnum.OperationAccessDeniedError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, OperationAccessDeniedErrorEnum.OperationAccessDeniedError]]: ...
        UNSPECIFIED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 0)
        UNKNOWN = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 1)
        ACTION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 2)
        CREATE_OPERATION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 3)
        REMOVE_OPERATION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 4)
        UPDATE_OPERATION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 5)
        MUTATE_ACTION_NOT_PERMITTED_FOR_CLIENT = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 6)
        OPERATION_NOT_PERMITTED_FOR_CAMPAIGN_TYPE = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 7)
        CREATE_AS_REMOVED_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 8)
        OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 9)
        OPERATION_NOT_PERMITTED_FOR_AD_GROUP_TYPE = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 10)
        MUTATE_NOT_PERMITTED_FOR_CUSTOMER = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 11)
    UNSPECIFIED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 0)
    UNKNOWN = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 1)
    ACTION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 2)
    CREATE_OPERATION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 3)
    REMOVE_OPERATION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 4)
    UPDATE_OPERATION_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 5)
    MUTATE_ACTION_NOT_PERMITTED_FOR_CLIENT = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 6)
    OPERATION_NOT_PERMITTED_FOR_CAMPAIGN_TYPE = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 7)
    CREATE_AS_REMOVED_NOT_PERMITTED = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 8)
    OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 9)
    OPERATION_NOT_PERMITTED_FOR_AD_GROUP_TYPE = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 10)
    MUTATE_NOT_PERMITTED_FOR_CUSTOMER = typing___cast(OperationAccessDeniedErrorEnum.OperationAccessDeniedError, 11)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> OperationAccessDeniedErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
