# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class PromotionPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class PromotionPlaceholderField(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> PromotionPlaceholderFieldEnum.PromotionPlaceholderField: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[PromotionPlaceholderFieldEnum.PromotionPlaceholderField]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, PromotionPlaceholderFieldEnum.PromotionPlaceholderField]]: ...
        UNSPECIFIED = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 0)
        UNKNOWN = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 1)
        PROMOTION_TARGET = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 2)
        DISCOUNT_MODIFIER = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 3)
        PERCENT_OFF = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 4)
        MONEY_AMOUNT_OFF = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 5)
        PROMOTION_CODE = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 6)
        ORDERS_OVER_AMOUNT = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 7)
        PROMOTION_START = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 8)
        PROMOTION_END = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 9)
        OCCASION = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 10)
        FINAL_URLS = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 11)
        FINAL_MOBILE_URLS = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 12)
        TRACKING_URL = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 13)
        LANGUAGE = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 14)
        FINAL_URL_SUFFIX = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 15)
    UNSPECIFIED = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 0)
    UNKNOWN = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 1)
    PROMOTION_TARGET = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 2)
    DISCOUNT_MODIFIER = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 3)
    PERCENT_OFF = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 4)
    MONEY_AMOUNT_OFF = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 5)
    PROMOTION_CODE = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 6)
    ORDERS_OVER_AMOUNT = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 7)
    PROMOTION_START = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 8)
    PROMOTION_END = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 9)
    OCCASION = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 10)
    FINAL_URLS = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 11)
    FINAL_MOBILE_URLS = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 12)
    TRACKING_URL = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 13)
    LANGUAGE = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 14)
    FINAL_URL_SUFFIX = typing___cast(PromotionPlaceholderFieldEnum.PromotionPlaceholderField, 15)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PromotionPlaceholderFieldEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
