# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class UserListSizeRangeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class UserListSizeRange(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> UserListSizeRangeEnum.UserListSizeRange: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[UserListSizeRangeEnum.UserListSizeRange]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, UserListSizeRangeEnum.UserListSizeRange]]: ...
        UNSPECIFIED = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 0)
        UNKNOWN = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 1)
        LESS_THAN_FIVE_HUNDRED = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 2)
        LESS_THAN_ONE_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 3)
        ONE_THOUSAND_TO_TEN_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 4)
        TEN_THOUSAND_TO_FIFTY_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 5)
        FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 6)
        ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 7)
        THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 8)
        FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 9)
        ONE_MILLION_TO_TWO_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 10)
        TWO_MILLION_TO_THREE_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 11)
        THREE_MILLION_TO_FIVE_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 12)
        FIVE_MILLION_TO_TEN_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 13)
        TEN_MILLION_TO_TWENTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 14)
        TWENTY_MILLION_TO_THIRTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 15)
        THIRTY_MILLION_TO_FIFTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 16)
        OVER_FIFTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 17)
    UNSPECIFIED = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 0)
    UNKNOWN = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 1)
    LESS_THAN_FIVE_HUNDRED = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 2)
    LESS_THAN_ONE_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 3)
    ONE_THOUSAND_TO_TEN_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 4)
    TEN_THOUSAND_TO_FIFTY_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 5)
    FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 6)
    ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 7)
    THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 8)
    FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 9)
    ONE_MILLION_TO_TWO_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 10)
    TWO_MILLION_TO_THREE_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 11)
    THREE_MILLION_TO_FIVE_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 12)
    FIVE_MILLION_TO_TEN_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 13)
    TEN_MILLION_TO_TWENTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 14)
    TWENTY_MILLION_TO_THIRTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 15)
    THIRTY_MILLION_TO_FIFTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 16)
    OVER_FIFTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRange, 17)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UserListSizeRangeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
