# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.served_asset_field_type_pb2 import (
    ServedAssetFieldTypeEnum as google___ads___googleads___v2___enums___served_asset_field_type_pb2___ServedAssetFieldTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class AdTextAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    pinned_field = ... # type: google___ads___googleads___v2___enums___served_asset_field_type_pb2___ServedAssetFieldTypeEnum.ServedAssetFieldType

    @property
    def text(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        text : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        pinned_field : typing___Optional[google___ads___googleads___v2___enums___served_asset_field_type_pb2___ServedAssetFieldTypeEnum.ServedAssetFieldType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdTextAsset: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"pinned_field",u"text"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"text",b"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"pinned_field",b"pinned_field",u"text",b"text"]) -> None: ...

class AdImageAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def asset(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        asset : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdImageAsset: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"asset"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"asset"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"asset",b"asset"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"asset",b"asset"]) -> None: ...

class AdVideoAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def asset(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        asset : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdVideoAsset: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"asset"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"asset"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"asset",b"asset"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"asset",b"asset"]) -> None: ...

class AdMediaBundleAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def asset(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        asset : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdMediaBundleAsset: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"asset"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"asset"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"asset",b"asset"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"asset",b"asset"]) -> None: ...
