# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.enums.matching_function_context_type_pb2 import (
    MatchingFunctionContextTypeEnum as google___ads___googleads___v1___enums___matching_function_context_type_pb2___MatchingFunctionContextTypeEnum,
)

from google.ads.google_ads.v1.proto.enums.matching_function_operator_pb2 import (
    MatchingFunctionOperatorEnum as google___ads___googleads___v1___enums___matching_function_operator_pb2___MatchingFunctionOperatorEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class MatchingFunction(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operator = ... # type: google___ads___googleads___v1___enums___matching_function_operator_pb2___MatchingFunctionOperatorEnum.MatchingFunctionOperator

    @property
    def function_string(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def left_operands(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[Operand]: ...

    @property
    def right_operands(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[Operand]: ...

    def __init__(self,
        *,
        function_string : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        operator : typing___Optional[google___ads___googleads___v1___enums___matching_function_operator_pb2___MatchingFunctionOperatorEnum.MatchingFunctionOperator] = None,
        left_operands : typing___Optional[typing___Iterable[Operand]] = None,
        right_operands : typing___Optional[typing___Iterable[Operand]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MatchingFunction: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"function_string"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"function_string",u"left_operands",u"operator",u"right_operands"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"function_string",b"function_string"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"function_string",b"function_string",u"left_operands",b"left_operands",u"operator",b"operator",u"right_operands",b"right_operands"]) -> None: ...

class Operand(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ConstantOperand(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def string_value(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def long_value(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def boolean_value(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

        @property
        def double_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

        def __init__(self,
            *,
            string_value : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            long_value : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            boolean_value : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
            double_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> Operand.ConstantOperand: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"boolean_value",u"constant_operand_value",u"double_value",u"long_value",u"string_value"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"boolean_value",u"constant_operand_value",u"double_value",u"long_value",u"string_value"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"boolean_value",b"boolean_value",u"constant_operand_value",b"constant_operand_value",u"double_value",b"double_value",u"long_value",b"long_value",u"string_value",b"string_value"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"boolean_value",b"boolean_value",u"constant_operand_value",b"constant_operand_value",u"double_value",b"double_value",u"long_value",b"long_value",u"string_value",b"string_value"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions___Literal[u"constant_operand_value",b"constant_operand_value"]) -> typing_extensions___Literal["string_value","long_value","boolean_value","double_value"]: ...

    class FeedAttributeOperand(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def feed_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def feed_attribute_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            feed_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            feed_attribute_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> Operand.FeedAttributeOperand: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"feed_attribute_id",u"feed_id"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"feed_attribute_id",u"feed_id"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"feed_attribute_id",b"feed_attribute_id",u"feed_id",b"feed_id"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"feed_attribute_id",b"feed_attribute_id",u"feed_id",b"feed_id"]) -> None: ...

    class FunctionOperand(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def matching_function(self) -> MatchingFunction: ...

        def __init__(self,
            *,
            matching_function : typing___Optional[MatchingFunction] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> Operand.FunctionOperand: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"matching_function"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"matching_function"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"matching_function",b"matching_function"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"matching_function",b"matching_function"]) -> None: ...

    class RequestContextOperand(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        context_type = ... # type: google___ads___googleads___v1___enums___matching_function_context_type_pb2___MatchingFunctionContextTypeEnum.MatchingFunctionContextType

        def __init__(self,
            *,
            context_type : typing___Optional[google___ads___googleads___v1___enums___matching_function_context_type_pb2___MatchingFunctionContextTypeEnum.MatchingFunctionContextType] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> Operand.RequestContextOperand: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def ClearField(self, field_name: typing_extensions___Literal[u"context_type"]) -> None: ...
        else:
            def ClearField(self, field_name: typing_extensions___Literal[u"context_type",b"context_type"]) -> None: ...


    @property
    def constant_operand(self) -> Operand.ConstantOperand: ...

    @property
    def feed_attribute_operand(self) -> Operand.FeedAttributeOperand: ...

    @property
    def function_operand(self) -> Operand.FunctionOperand: ...

    @property
    def request_context_operand(self) -> Operand.RequestContextOperand: ...

    def __init__(self,
        *,
        constant_operand : typing___Optional[Operand.ConstantOperand] = None,
        feed_attribute_operand : typing___Optional[Operand.FeedAttributeOperand] = None,
        function_operand : typing___Optional[Operand.FunctionOperand] = None,
        request_context_operand : typing___Optional[Operand.RequestContextOperand] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> Operand: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"constant_operand",u"feed_attribute_operand",u"function_argument_operand",u"function_operand",u"request_context_operand"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"constant_operand",u"feed_attribute_operand",u"function_argument_operand",u"function_operand",u"request_context_operand"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"constant_operand",b"constant_operand",u"feed_attribute_operand",b"feed_attribute_operand",u"function_argument_operand",b"function_argument_operand",u"function_operand",b"function_operand",u"request_context_operand",b"request_context_operand"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"constant_operand",b"constant_operand",u"feed_attribute_operand",b"feed_attribute_operand",u"function_argument_operand",b"function_argument_operand",u"function_operand",b"function_operand",u"request_context_operand",b"request_context_operand"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"function_argument_operand",b"function_argument_operand"]) -> typing_extensions___Literal["constant_operand","feed_attribute_operand","function_operand","request_context_operand"]: ...
