# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class MutateErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class MutateError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> MutateErrorEnum.MutateError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[MutateErrorEnum.MutateError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, MutateErrorEnum.MutateError]]: ...
        UNSPECIFIED = typing___cast(MutateErrorEnum.MutateError, 0)
        UNKNOWN = typing___cast(MutateErrorEnum.MutateError, 1)
        RESOURCE_NOT_FOUND = typing___cast(MutateErrorEnum.MutateError, 3)
        ID_EXISTS_IN_MULTIPLE_MUTATES = typing___cast(MutateErrorEnum.MutateError, 7)
        INCONSISTENT_FIELD_VALUES = typing___cast(MutateErrorEnum.MutateError, 8)
        MUTATE_NOT_ALLOWED = typing___cast(MutateErrorEnum.MutateError, 9)
        RESOURCE_NOT_IN_GOOGLE_ADS = typing___cast(MutateErrorEnum.MutateError, 10)
        RESOURCE_ALREADY_EXISTS = typing___cast(MutateErrorEnum.MutateError, 11)
    UNSPECIFIED = typing___cast(MutateErrorEnum.MutateError, 0)
    UNKNOWN = typing___cast(MutateErrorEnum.MutateError, 1)
    RESOURCE_NOT_FOUND = typing___cast(MutateErrorEnum.MutateError, 3)
    ID_EXISTS_IN_MULTIPLE_MUTATES = typing___cast(MutateErrorEnum.MutateError, 7)
    INCONSISTENT_FIELD_VALUES = typing___cast(MutateErrorEnum.MutateError, 8)
    MUTATE_NOT_ALLOWED = typing___cast(MutateErrorEnum.MutateError, 9)
    RESOURCE_NOT_IN_GOOGLE_ADS = typing___cast(MutateErrorEnum.MutateError, 10)
    RESOURCE_ALREADY_EXISTS = typing___cast(MutateErrorEnum.MutateError, 11)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
