# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.media_type_pb2 import (
    MediaTypeEnum as google___ads___googleads___v2___enums___media_type_pb2___MediaTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.mime_type_pb2 import (
    MimeTypeEnum as google___ads___googleads___v2___enums___mime_type_pb2___MimeTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BytesValue as google___protobuf___wrappers_pb2___BytesValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class MediaFile(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    type = ... # type: google___ads___googleads___v2___enums___media_type_pb2___MediaTypeEnum.MediaType
    mime_type = ... # type: google___ads___googleads___v2___enums___mime_type_pb2___MimeTypeEnum.MimeType

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def source_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def file_size(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def image(self) -> MediaImage: ...

    @property
    def media_bundle(self) -> MediaBundle: ...

    @property
    def audio(self) -> MediaAudio: ...

    @property
    def video(self) -> MediaVideo: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        type : typing___Optional[google___ads___googleads___v2___enums___media_type_pb2___MediaTypeEnum.MediaType] = None,
        mime_type : typing___Optional[google___ads___googleads___v2___enums___mime_type_pb2___MimeTypeEnum.MimeType] = None,
        source_url : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        file_size : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        image : typing___Optional[MediaImage] = None,
        media_bundle : typing___Optional[MediaBundle] = None,
        audio : typing___Optional[MediaAudio] = None,
        video : typing___Optional[MediaVideo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MediaFile: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"audio",u"file_size",u"id",u"image",u"media_bundle",u"mediatype",u"name",u"source_url",u"video"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"audio",u"file_size",u"id",u"image",u"media_bundle",u"mediatype",u"mime_type",u"name",u"resource_name",u"source_url",u"type",u"video"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"audio",b"audio",u"file_size",b"file_size",u"id",b"id",u"image",b"image",u"media_bundle",b"media_bundle",u"mediatype",b"mediatype",u"name",b"name",u"source_url",b"source_url",u"video",b"video"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"audio",b"audio",u"file_size",b"file_size",u"id",b"id",u"image",b"image",u"media_bundle",b"media_bundle",u"mediatype",b"mediatype",u"mime_type",b"mime_type",u"name",b"name",u"resource_name",b"resource_name",u"source_url",b"source_url",u"type",b"type",u"video",b"video"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"mediatype",b"mediatype"]) -> typing_extensions___Literal["image","media_bundle","audio","video"]: ...

class MediaImage(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def data(self) -> google___protobuf___wrappers_pb2___BytesValue: ...

    def __init__(self,
        *,
        data : typing___Optional[google___protobuf___wrappers_pb2___BytesValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MediaImage: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"data"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"data"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"data",b"data"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"data",b"data"]) -> None: ...

class MediaBundle(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def data(self) -> google___protobuf___wrappers_pb2___BytesValue: ...

    def __init__(self,
        *,
        data : typing___Optional[google___protobuf___wrappers_pb2___BytesValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MediaBundle: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"data"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"data"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"data",b"data"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"data",b"data"]) -> None: ...

class MediaAudio(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def ad_duration_millis(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        ad_duration_millis : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MediaAudio: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_duration_millis"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_duration_millis"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_duration_millis",b"ad_duration_millis"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_duration_millis",b"ad_duration_millis"]) -> None: ...

class MediaVideo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def ad_duration_millis(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def youtube_video_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def advertising_id_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def isci_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        ad_duration_millis : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        youtube_video_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        advertising_id_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        isci_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MediaVideo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_duration_millis",u"advertising_id_code",u"isci_code",u"youtube_video_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_duration_millis",u"advertising_id_code",u"isci_code",u"youtube_video_id"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_duration_millis",b"ad_duration_millis",u"advertising_id_code",b"advertising_id_code",u"isci_code",b"isci_code",u"youtube_video_id",b"youtube_video_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_duration_millis",b"ad_duration_millis",u"advertising_id_code",b"advertising_id_code",u"isci_code",b"isci_code",u"youtube_video_id",b"youtube_video_id"]) -> None: ...
