# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class MediaFileErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class MediaFileError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> MediaFileErrorEnum.MediaFileError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[MediaFileErrorEnum.MediaFileError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, MediaFileErrorEnum.MediaFileError]]: ...
        UNSPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileError, 0)
        UNKNOWN = typing___cast(MediaFileErrorEnum.MediaFileError, 1)
        CANNOT_CREATE_STANDARD_ICON = typing___cast(MediaFileErrorEnum.MediaFileError, 2)
        CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES = typing___cast(MediaFileErrorEnum.MediaFileError, 3)
        CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA = typing___cast(MediaFileErrorEnum.MediaFileError, 4)
        DUPLICATE_MEDIA = typing___cast(MediaFileErrorEnum.MediaFileError, 5)
        EMPTY_FIELD = typing___cast(MediaFileErrorEnum.MediaFileError, 6)
        RESOURCE_REFERENCED_IN_MULTIPLE_OPS = typing___cast(MediaFileErrorEnum.MediaFileError, 7)
        FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 8)
        INVALID_MEDIA_FILE_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 9)
        INVALID_MEDIA_SUB_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 10)
        INVALID_MEDIA_FILE_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 11)
        INVALID_MIME_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 12)
        INVALID_REFERENCE_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 13)
        INVALID_YOU_TUBE_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 14)
        MEDIA_FILE_FAILED_TRANSCODING = typing___cast(MediaFileErrorEnum.MediaFileError, 15)
        MEDIA_NOT_TRANSCODED = typing___cast(MediaFileErrorEnum.MediaFileError, 16)
        MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 17)
        NO_FIELDS_SPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileError, 18)
        NULL_REFERENCE_ID_AND_MEDIA_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 19)
        TOO_LONG = typing___cast(MediaFileErrorEnum.MediaFileError, 20)
        UNSUPPORTED_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 21)
        YOU_TUBE_SERVICE_UNAVAILABLE = typing___cast(MediaFileErrorEnum.MediaFileError, 22)
        YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION = typing___cast(MediaFileErrorEnum.MediaFileError, 23)
        YOU_TUBE_VIDEO_NOT_FOUND = typing___cast(MediaFileErrorEnum.MediaFileError, 24)
    UNSPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileError, 0)
    UNKNOWN = typing___cast(MediaFileErrorEnum.MediaFileError, 1)
    CANNOT_CREATE_STANDARD_ICON = typing___cast(MediaFileErrorEnum.MediaFileError, 2)
    CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES = typing___cast(MediaFileErrorEnum.MediaFileError, 3)
    CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA = typing___cast(MediaFileErrorEnum.MediaFileError, 4)
    DUPLICATE_MEDIA = typing___cast(MediaFileErrorEnum.MediaFileError, 5)
    EMPTY_FIELD = typing___cast(MediaFileErrorEnum.MediaFileError, 6)
    RESOURCE_REFERENCED_IN_MULTIPLE_OPS = typing___cast(MediaFileErrorEnum.MediaFileError, 7)
    FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 8)
    INVALID_MEDIA_FILE_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 9)
    INVALID_MEDIA_SUB_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 10)
    INVALID_MEDIA_FILE_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 11)
    INVALID_MIME_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 12)
    INVALID_REFERENCE_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 13)
    INVALID_YOU_TUBE_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 14)
    MEDIA_FILE_FAILED_TRANSCODING = typing___cast(MediaFileErrorEnum.MediaFileError, 15)
    MEDIA_NOT_TRANSCODED = typing___cast(MediaFileErrorEnum.MediaFileError, 16)
    MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 17)
    NO_FIELDS_SPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileError, 18)
    NULL_REFERENCE_ID_AND_MEDIA_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 19)
    TOO_LONG = typing___cast(MediaFileErrorEnum.MediaFileError, 20)
    UNSUPPORTED_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 21)
    YOU_TUBE_SERVICE_UNAVAILABLE = typing___cast(MediaFileErrorEnum.MediaFileError, 22)
    YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION = typing___cast(MediaFileErrorEnum.MediaFileError, 23)
    YOU_TUBE_VIDEO_NOT_FOUND = typing___cast(MediaFileErrorEnum.MediaFileError, 24)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MediaFileErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
