# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class CampaignCriterionErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CampaignCriterionError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> CampaignCriterionErrorEnum.CampaignCriterionError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[CampaignCriterionErrorEnum.CampaignCriterionError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, CampaignCriterionErrorEnum.CampaignCriterionError]]: ...
        UNSPECIFIED = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 0)
        UNKNOWN = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 1)
        CONCRETE_TYPE_REQUIRED = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 2)
        INVALID_PLACEMENT_URL = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 3)
        CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 4)
        CANNOT_SET_STATUS_FOR_CRITERIA_TYPE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 5)
        CANNOT_SET_STATUS_FOR_EXCLUDED_CRITERIA = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 6)
        CANNOT_TARGET_AND_EXCLUDE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 7)
        TOO_MANY_OPERATIONS = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 8)
        OPERATOR_NOT_SUPPORTED_FOR_CRITERION_TYPE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 9)
        SHOPPING_CAMPAIGN_SALES_COUNTRY_NOT_SUPPORTED_FOR_SALES_CHANNEL = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 10)
        CANNOT_ADD_EXISTING_FIELD = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 11)
        CANNOT_UPDATE_NEGATIVE_CRITERION = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 12)
    UNSPECIFIED = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 0)
    UNKNOWN = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 1)
    CONCRETE_TYPE_REQUIRED = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 2)
    INVALID_PLACEMENT_URL = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 3)
    CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 4)
    CANNOT_SET_STATUS_FOR_CRITERIA_TYPE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 5)
    CANNOT_SET_STATUS_FOR_EXCLUDED_CRITERIA = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 6)
    CANNOT_TARGET_AND_EXCLUDE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 7)
    TOO_MANY_OPERATIONS = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 8)
    OPERATOR_NOT_SUPPORTED_FOR_CRITERION_TYPE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 9)
    SHOPPING_CAMPAIGN_SALES_COUNTRY_NOT_SUPPORTED_FOR_SALES_CHANNEL = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 10)
    CANNOT_ADD_EXISTING_FIELD = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 11)
    CANNOT_UPDATE_NEGATIVE_CRITERION = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 12)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CampaignCriterionErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
