# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class AttributionModelEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AttributionModel(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> AttributionModelEnum.AttributionModel: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[AttributionModelEnum.AttributionModel]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, AttributionModelEnum.AttributionModel]]: ...
        UNSPECIFIED = typing___cast(AttributionModelEnum.AttributionModel, 0)
        UNKNOWN = typing___cast(AttributionModelEnum.AttributionModel, 1)
        EXTERNAL = typing___cast(AttributionModelEnum.AttributionModel, 100)
        GOOGLE_ADS_LAST_CLICK = typing___cast(AttributionModelEnum.AttributionModel, 101)
        GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK = typing___cast(AttributionModelEnum.AttributionModel, 102)
        GOOGLE_SEARCH_ATTRIBUTION_LINEAR = typing___cast(AttributionModelEnum.AttributionModel, 103)
        GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY = typing___cast(AttributionModelEnum.AttributionModel, 104)
        GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED = typing___cast(AttributionModelEnum.AttributionModel, 105)
        GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN = typing___cast(AttributionModelEnum.AttributionModel, 106)
    UNSPECIFIED = typing___cast(AttributionModelEnum.AttributionModel, 0)
    UNKNOWN = typing___cast(AttributionModelEnum.AttributionModel, 1)
    EXTERNAL = typing___cast(AttributionModelEnum.AttributionModel, 100)
    GOOGLE_ADS_LAST_CLICK = typing___cast(AttributionModelEnum.AttributionModel, 101)
    GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK = typing___cast(AttributionModelEnum.AttributionModel, 102)
    GOOGLE_SEARCH_ATTRIBUTION_LINEAR = typing___cast(AttributionModelEnum.AttributionModel, 103)
    GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY = typing___cast(AttributionModelEnum.AttributionModel, 104)
    GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED = typing___cast(AttributionModelEnum.AttributionModel, 105)
    GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN = typing___cast(AttributionModelEnum.AttributionModel, 106)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AttributionModelEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
