# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class FeedItemValidationErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class FeedItemValidationError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> FeedItemValidationErrorEnum.FeedItemValidationError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[FeedItemValidationErrorEnum.FeedItemValidationError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, FeedItemValidationErrorEnum.FeedItemValidationError]]: ...
        UNSPECIFIED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 0)
        UNKNOWN = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 1)
        STRING_TOO_SHORT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 2)
        STRING_TOO_LONG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 3)
        VALUE_NOT_SPECIFIED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 4)
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 5)
        INVALID_PHONE_NUMBER = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 6)
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 7)
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 8)
        DISALLOWED_NUMBER_TYPE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 9)
        VALUE_OUT_OF_RANGE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 10)
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 11)
        CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 12)
        INVALID_COUNTRY_CODE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 13)
        INVALID_APP_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 14)
        MISSING_ATTRIBUTES_FOR_FIELDS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 15)
        INVALID_TYPE_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 16)
        INVALID_EMAIL_ADDRESS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 17)
        INVALID_HTTPS_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 18)
        MISSING_DELIVERY_ADDRESS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 19)
        START_DATE_AFTER_END_DATE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 20)
        MISSING_FEED_ITEM_START_TIME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 21)
        MISSING_FEED_ITEM_END_TIME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 22)
        MISSING_FEED_ITEM_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 23)
        VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 24)
        INVALID_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 25)
        INVALID_NUMBER_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 26)
        INVALID_DATE_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 27)
        INVALID_PRICE_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 28)
        UNKNOWN_PLACEHOLDER_FIELD = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 29)
        MISSING_ENHANCED_SITELINK_DESCRIPTION_LINE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 30)
        REVIEW_EXTENSION_SOURCE_INELIGIBLE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 31)
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 32)
        DOUBLE_QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 33)
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 34)
        INVALID_FORM_ENCODED_PARAMS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 35)
        INVALID_URL_PARAMETER_NAME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 36)
        NO_GEOCODING_RESULT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 37)
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 38)
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 39)
        INVALID_PLACEHOLDER_FIELD_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 40)
        INVALID_URL_TAG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 41)
        LIST_TOO_LONG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 42)
        INVALID_ATTRIBUTES_COMBINATION = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 43)
        DUPLICATE_VALUES = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 44)
        INVALID_CALL_CONVERSION_ACTION_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 45)
        CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 46)
        APP_ID_DOESNT_EXIST_IN_APP_STORE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 47)
        INVALID_FINAL_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 48)
        INVALID_TRACKING_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 49)
        INVALID_FINAL_URL_FOR_APP_DOWNLOAD_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 50)
        LIST_TOO_SHORT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 51)
        INVALID_USER_ACTION = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 52)
        INVALID_TYPE_NAME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 53)
        INVALID_EVENT_CHANGE_STATUS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 54)
        INVALID_SNIPPETS_HEADER = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 55)
        INVALID_ANDROID_APP_LINK = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 56)
        NUMBER_TYPE_WITH_CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 57)
        RESERVED_KEYWORD_OTHER = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 58)
        DUPLICATE_OPTION_LABELS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 59)
        DUPLICATE_OPTION_PREFILLS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 60)
        UNEQUAL_LIST_LENGTHS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 61)
        INCONSISTENT_CURRENCY_CODES = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 62)
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 63)
        ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 64)
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 65)
        UNSUPPORTED_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 66)
        INVALID_FINAL_MOBILE_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 67)
        INVALID_KEYWORDLESS_AD_RULE_LABEL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 68)
        VALUE_TRACK_PARAMETER_NOT_SUPPORTED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 69)
        UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 70)
        INVALID_IOS_APP_LINK = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 71)
        MISSING_IOS_APP_LINK_OR_IOS_APP_STORE_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 72)
        PROMOTION_INVALID_TIME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 73)
        PROMOTION_CANNOT_SET_PERCENT_OFF_AND_MONEY_AMOUNT_OFF = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 74)
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 75)
        TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 76)
        AD_CUSTOMIZERS_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 77)
        INVALID_LANGUAGE_CODE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 78)
        UNSUPPORTED_LANGUAGE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 79)
        IF_FUNCTION_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 80)
        INVALID_FINAL_URL_SUFFIX = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 81)
        INVALID_TAG_IN_FINAL_URL_SUFFIX = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 82)
        INVALID_FINAL_URL_SUFFIX_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 83)
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 84)
        ONLY_ONE_DELIVERY_OPTION_IS_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 85)
        NO_DELIVERY_OPTION_IS_SET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 86)
        INVALID_CONVERSION_REPORTING_STATE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 87)
        IMAGE_SIZE_WRONG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 88)
        EMAIL_DELIVERY_NOT_AVAILABLE_IN_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 89)
        AUTO_REPLY_NOT_AVAILABLE_IN_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 90)
        INVALID_LATITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 91)
        INVALID_LONGITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 92)
        TOO_MANY_LABELS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 93)
        INVALID_IMAGE_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 94)
        MISSING_LATITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 95)
        MISSING_LONGITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 96)
        ADDRESS_NOT_FOUND = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 97)
        ADDRESS_NOT_TARGETABLE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 98)
    UNSPECIFIED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 0)
    UNKNOWN = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 1)
    STRING_TOO_SHORT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 2)
    STRING_TOO_LONG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 3)
    VALUE_NOT_SPECIFIED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 4)
    INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 5)
    INVALID_PHONE_NUMBER = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 6)
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 7)
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 8)
    DISALLOWED_NUMBER_TYPE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 9)
    VALUE_OUT_OF_RANGE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 10)
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 11)
    CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 12)
    INVALID_COUNTRY_CODE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 13)
    INVALID_APP_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 14)
    MISSING_ATTRIBUTES_FOR_FIELDS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 15)
    INVALID_TYPE_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 16)
    INVALID_EMAIL_ADDRESS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 17)
    INVALID_HTTPS_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 18)
    MISSING_DELIVERY_ADDRESS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 19)
    START_DATE_AFTER_END_DATE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 20)
    MISSING_FEED_ITEM_START_TIME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 21)
    MISSING_FEED_ITEM_END_TIME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 22)
    MISSING_FEED_ITEM_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 23)
    VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 24)
    INVALID_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 25)
    INVALID_NUMBER_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 26)
    INVALID_DATE_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 27)
    INVALID_PRICE_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 28)
    UNKNOWN_PLACEHOLDER_FIELD = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 29)
    MISSING_ENHANCED_SITELINK_DESCRIPTION_LINE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 30)
    REVIEW_EXTENSION_SOURCE_INELIGIBLE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 31)
    HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 32)
    DOUBLE_QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 33)
    QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 34)
    INVALID_FORM_ENCODED_PARAMS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 35)
    INVALID_URL_PARAMETER_NAME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 36)
    NO_GEOCODING_RESULT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 37)
    SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 38)
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 39)
    INVALID_PLACEHOLDER_FIELD_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 40)
    INVALID_URL_TAG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 41)
    LIST_TOO_LONG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 42)
    INVALID_ATTRIBUTES_COMBINATION = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 43)
    DUPLICATE_VALUES = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 44)
    INVALID_CALL_CONVERSION_ACTION_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 45)
    CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 46)
    APP_ID_DOESNT_EXIST_IN_APP_STORE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 47)
    INVALID_FINAL_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 48)
    INVALID_TRACKING_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 49)
    INVALID_FINAL_URL_FOR_APP_DOWNLOAD_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 50)
    LIST_TOO_SHORT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 51)
    INVALID_USER_ACTION = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 52)
    INVALID_TYPE_NAME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 53)
    INVALID_EVENT_CHANGE_STATUS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 54)
    INVALID_SNIPPETS_HEADER = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 55)
    INVALID_ANDROID_APP_LINK = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 56)
    NUMBER_TYPE_WITH_CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 57)
    RESERVED_KEYWORD_OTHER = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 58)
    DUPLICATE_OPTION_LABELS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 59)
    DUPLICATE_OPTION_PREFILLS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 60)
    UNEQUAL_LIST_LENGTHS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 61)
    INCONSISTENT_CURRENCY_CODES = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 62)
    PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 63)
    ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 64)
    PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 65)
    UNSUPPORTED_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 66)
    INVALID_FINAL_MOBILE_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 67)
    INVALID_KEYWORDLESS_AD_RULE_LABEL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 68)
    VALUE_TRACK_PARAMETER_NOT_SUPPORTED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 69)
    UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 70)
    INVALID_IOS_APP_LINK = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 71)
    MISSING_IOS_APP_LINK_OR_IOS_APP_STORE_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 72)
    PROMOTION_INVALID_TIME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 73)
    PROMOTION_CANNOT_SET_PERCENT_OFF_AND_MONEY_AMOUNT_OFF = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 74)
    PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 75)
    TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 76)
    AD_CUSTOMIZERS_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 77)
    INVALID_LANGUAGE_CODE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 78)
    UNSUPPORTED_LANGUAGE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 79)
    IF_FUNCTION_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 80)
    INVALID_FINAL_URL_SUFFIX = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 81)
    INVALID_TAG_IN_FINAL_URL_SUFFIX = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 82)
    INVALID_FINAL_URL_SUFFIX_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 83)
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 84)
    ONLY_ONE_DELIVERY_OPTION_IS_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 85)
    NO_DELIVERY_OPTION_IS_SET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 86)
    INVALID_CONVERSION_REPORTING_STATE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 87)
    IMAGE_SIZE_WRONG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 88)
    EMAIL_DELIVERY_NOT_AVAILABLE_IN_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 89)
    AUTO_REPLY_NOT_AVAILABLE_IN_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 90)
    INVALID_LATITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 91)
    INVALID_LONGITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 92)
    TOO_MANY_LABELS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 93)
    INVALID_IMAGE_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 94)
    MISSING_LATITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 95)
    MISSING_LONGITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 96)
    ADDRESS_NOT_FOUND = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 97)
    ADDRESS_NOT_TARGETABLE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 98)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedItemValidationErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
