# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ExtensionFeedItemErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ExtensionFeedItemError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ExtensionFeedItemErrorEnum.ExtensionFeedItemError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ExtensionFeedItemErrorEnum.ExtensionFeedItemError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ExtensionFeedItemErrorEnum.ExtensionFeedItemError]]: ...
        UNSPECIFIED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 0)
        UNKNOWN = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 1)
        VALUE_OUT_OF_RANGE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 2)
        URL_LIST_TOO_LONG = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 3)
        CANNOT_HAVE_RESTRICTION_ON_EMPTY_GEO_TARGETING = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 4)
        CANNOT_SET_WITH_FINAL_URLS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 5)
        CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 6)
        INVALID_PHONE_NUMBER = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 7)
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 8)
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 9)
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 10)
        DISALLOWED_NUMBER_TYPE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 11)
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 12)
        VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 13)
        INVALID_CALL_CONVERSION_ACTION = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 14)
        CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 15)
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 16)
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 17)
        INVALID_APP_ID = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 18)
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 19)
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 20)
        REVIEW_EXTENSION_SOURCE_INELIGIBLE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 21)
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 22)
        INCONSISTENT_CURRENCY_CODES = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 23)
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 24)
        PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 25)
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 26)
        PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 27)
        UNSUPPORTED_VALUE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 28)
        UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 29)
        INVALID_DEVICE_PREFERENCE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 30)
        INVALID_SCHEDULE_END = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 31)
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 32)
        INVALID_SNIPPETS_HEADER = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 33)
        CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 34)
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 35)
        CONFLICTING_CALL_CONVERSION_SETTINGS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 36)
        EXTENSION_TYPE_MISMATCH = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 37)
        EXTENSION_SUBTYPE_REQUIRED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 38)
        EXTENSION_TYPE_UNSUPPORTED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 39)
        CANNOT_OPERATE_ON_FEED_WITH_MULTIPLE_MAPPINGS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 40)
        CANNOT_OPERATE_ON_FEED_WITH_KEY_ATTRIBUTES = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 41)
        INVALID_PRICE_FORMAT = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 42)
        PROMOTION_INVALID_TIME = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 43)
        TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 44)
    UNSPECIFIED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 0)
    UNKNOWN = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 1)
    VALUE_OUT_OF_RANGE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 2)
    URL_LIST_TOO_LONG = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 3)
    CANNOT_HAVE_RESTRICTION_ON_EMPTY_GEO_TARGETING = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 4)
    CANNOT_SET_WITH_FINAL_URLS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 5)
    CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 6)
    INVALID_PHONE_NUMBER = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 7)
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 8)
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 9)
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 10)
    DISALLOWED_NUMBER_TYPE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 11)
    INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 12)
    VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 13)
    INVALID_CALL_CONVERSION_ACTION = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 14)
    CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 15)
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 16)
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 17)
    INVALID_APP_ID = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 18)
    QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 19)
    HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 20)
    REVIEW_EXTENSION_SOURCE_INELIGIBLE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 21)
    SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 22)
    INCONSISTENT_CURRENCY_CODES = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 23)
    PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 24)
    PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 25)
    PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 26)
    PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 27)
    UNSUPPORTED_VALUE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 28)
    UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 29)
    INVALID_DEVICE_PREFERENCE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 30)
    INVALID_SCHEDULE_END = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 31)
    DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 32)
    INVALID_SNIPPETS_HEADER = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 33)
    CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 34)
    PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 35)
    CONFLICTING_CALL_CONVERSION_SETTINGS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 36)
    EXTENSION_TYPE_MISMATCH = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 37)
    EXTENSION_SUBTYPE_REQUIRED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 38)
    EXTENSION_TYPE_UNSUPPORTED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 39)
    CANNOT_OPERATE_ON_FEED_WITH_MULTIPLE_MAPPINGS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 40)
    CANNOT_OPERATE_ON_FEED_WITH_KEY_ATTRIBUTES = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 41)
    INVALID_PRICE_FORMAT = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 42)
    PROMOTION_INVALID_TIME = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 43)
    TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 44)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ExtensionFeedItemErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
