# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class CustomInterestErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CustomInterestError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> CustomInterestErrorEnum.CustomInterestError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[CustomInterestErrorEnum.CustomInterestError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, CustomInterestErrorEnum.CustomInterestError]]: ...
        UNSPECIFIED = typing___cast(CustomInterestErrorEnum.CustomInterestError, 0)
        UNKNOWN = typing___cast(CustomInterestErrorEnum.CustomInterestError, 1)
        NAME_ALREADY_USED = typing___cast(CustomInterestErrorEnum.CustomInterestError, 2)
        CUSTOM_INTEREST_MEMBER_ID_AND_TYPE_PARAMETER_NOT_PRESENT_IN_REMOVE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 3)
        TYPE_AND_PARAMETER_NOT_FOUND = typing___cast(CustomInterestErrorEnum.CustomInterestError, 4)
        TYPE_AND_PARAMETER_ALREADY_EXISTED = typing___cast(CustomInterestErrorEnum.CustomInterestError, 5)
        INVALID_CUSTOM_INTEREST_MEMBER_TYPE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 6)
        CANNOT_REMOVE_WHILE_IN_USE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 7)
        CANNOT_CHANGE_TYPE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 8)
    UNSPECIFIED = typing___cast(CustomInterestErrorEnum.CustomInterestError, 0)
    UNKNOWN = typing___cast(CustomInterestErrorEnum.CustomInterestError, 1)
    NAME_ALREADY_USED = typing___cast(CustomInterestErrorEnum.CustomInterestError, 2)
    CUSTOM_INTEREST_MEMBER_ID_AND_TYPE_PARAMETER_NOT_PRESENT_IN_REMOVE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 3)
    TYPE_AND_PARAMETER_NOT_FOUND = typing___cast(CustomInterestErrorEnum.CustomInterestError, 4)
    TYPE_AND_PARAMETER_ALREADY_EXISTED = typing___cast(CustomInterestErrorEnum.CustomInterestError, 5)
    INVALID_CUSTOM_INTEREST_MEMBER_TYPE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 6)
    CANNOT_REMOVE_WHILE_IN_USE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 7)
    CANNOT_CHANGE_TYPE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 8)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CustomInterestErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
