# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.common.criteria_pb2 import (
    AdScheduleInfo as google___ads___googleads___v1___common___criteria_pb2___AdScheduleInfo,
    KeywordInfo as google___ads___googleads___v1___common___criteria_pb2___KeywordInfo,
)

from google.ads.google_ads.v1.proto.enums.feed_item_target_device_pb2 import (
    FeedItemTargetDeviceEnum as google___ads___googleads___v1___enums___feed_item_target_device_pb2___FeedItemTargetDeviceEnum,
)

from google.ads.google_ads.v1.proto.enums.feed_item_target_type_pb2 import (
    FeedItemTargetTypeEnum as google___ads___googleads___v1___enums___feed_item_target_type_pb2___FeedItemTargetTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class FeedItemTarget(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    feed_item_target_type = ... # type: google___ads___googleads___v1___enums___feed_item_target_type_pb2___FeedItemTargetTypeEnum.FeedItemTargetType
    device = ... # type: google___ads___googleads___v1___enums___feed_item_target_device_pb2___FeedItemTargetDeviceEnum.FeedItemTargetDevice

    @property
    def feed_item(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def feed_item_target_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def keyword(self) -> google___ads___googleads___v1___common___criteria_pb2___KeywordInfo: ...

    @property
    def geo_target_constant(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def ad_schedule(self) -> google___ads___googleads___v1___common___criteria_pb2___AdScheduleInfo: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        feed_item : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        feed_item_target_type : typing___Optional[google___ads___googleads___v1___enums___feed_item_target_type_pb2___FeedItemTargetTypeEnum.FeedItemTargetType] = None,
        feed_item_target_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        campaign : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        keyword : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___KeywordInfo] = None,
        geo_target_constant : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        device : typing___Optional[google___ads___googleads___v1___enums___feed_item_target_device_pb2___FeedItemTargetDeviceEnum.FeedItemTargetDevice] = None,
        ad_schedule : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___AdScheduleInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedItemTarget: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group",u"ad_schedule",u"campaign",u"device",u"feed_item",u"feed_item_target_id",u"geo_target_constant",u"keyword",u"target"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",u"ad_schedule",u"campaign",u"device",u"feed_item",u"feed_item_target_id",u"feed_item_target_type",u"geo_target_constant",u"keyword",u"resource_name",u"target"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"ad_schedule",b"ad_schedule",u"campaign",b"campaign",u"device",b"device",u"feed_item",b"feed_item",u"feed_item_target_id",b"feed_item_target_id",u"geo_target_constant",b"geo_target_constant",u"keyword",b"keyword",u"target",b"target"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"ad_schedule",b"ad_schedule",u"campaign",b"campaign",u"device",b"device",u"feed_item",b"feed_item",u"feed_item_target_id",b"feed_item_target_id",u"feed_item_target_type",b"feed_item_target_type",u"geo_target_constant",b"geo_target_constant",u"keyword",b"keyword",u"resource_name",b"resource_name",u"target",b"target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"target",b"target"]) -> typing_extensions___Literal["campaign","ad_group","keyword","geo_target_constant","device","ad_schedule"]: ...
