# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class LocalPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class LocalPlaceholderField(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> LocalPlaceholderFieldEnum.LocalPlaceholderField: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[LocalPlaceholderFieldEnum.LocalPlaceholderField]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, LocalPlaceholderFieldEnum.LocalPlaceholderField]]: ...
        UNSPECIFIED = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 0)
        UNKNOWN = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 1)
        DEAL_ID = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 2)
        DEAL_NAME = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 3)
        SUBTITLE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 4)
        DESCRIPTION = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 5)
        PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 6)
        FORMATTED_PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 7)
        SALE_PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 8)
        FORMATTED_SALE_PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 9)
        IMAGE_URL = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 10)
        ADDRESS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 11)
        CATEGORY = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 12)
        CONTEXTUAL_KEYWORDS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 13)
        FINAL_URLS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 14)
        FINAL_MOBILE_URLS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 15)
        TRACKING_URL = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 16)
        ANDROID_APP_LINK = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 17)
        SIMILAR_DEAL_IDS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 18)
        IOS_APP_LINK = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 19)
        IOS_APP_STORE_ID = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 20)
    UNSPECIFIED = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 0)
    UNKNOWN = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 1)
    DEAL_ID = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 2)
    DEAL_NAME = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 3)
    SUBTITLE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 4)
    DESCRIPTION = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 5)
    PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 6)
    FORMATTED_PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 7)
    SALE_PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 8)
    FORMATTED_SALE_PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 9)
    IMAGE_URL = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 10)
    ADDRESS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 11)
    CATEGORY = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 12)
    CONTEXTUAL_KEYWORDS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 13)
    FINAL_URLS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 14)
    FINAL_MOBILE_URLS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 15)
    TRACKING_URL = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 16)
    ANDROID_APP_LINK = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 17)
    SIMILAR_DEAL_IDS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 18)
    IOS_APP_LINK = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 19)
    IOS_APP_STORE_ID = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 20)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> LocalPlaceholderFieldEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
