# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class RecommendationTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class RecommendationType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> RecommendationTypeEnum.RecommendationType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[RecommendationTypeEnum.RecommendationType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, RecommendationTypeEnum.RecommendationType]]: ...
        UNSPECIFIED = typing___cast(RecommendationTypeEnum.RecommendationType, 0)
        UNKNOWN = typing___cast(RecommendationTypeEnum.RecommendationType, 1)
        CAMPAIGN_BUDGET = typing___cast(RecommendationTypeEnum.RecommendationType, 2)
        KEYWORD = typing___cast(RecommendationTypeEnum.RecommendationType, 3)
        TEXT_AD = typing___cast(RecommendationTypeEnum.RecommendationType, 4)
        TARGET_CPA_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 5)
        MAXIMIZE_CONVERSIONS_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 6)
        ENHANCED_CPC_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 7)
        SEARCH_PARTNERS_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 8)
        MAXIMIZE_CLICKS_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 9)
        OPTIMIZE_AD_ROTATION = typing___cast(RecommendationTypeEnum.RecommendationType, 10)
        CALLOUT_EXTENSION = typing___cast(RecommendationTypeEnum.RecommendationType, 11)
        SITELINK_EXTENSION = typing___cast(RecommendationTypeEnum.RecommendationType, 12)
        CALL_EXTENSION = typing___cast(RecommendationTypeEnum.RecommendationType, 13)
        KEYWORD_MATCH_TYPE = typing___cast(RecommendationTypeEnum.RecommendationType, 14)
        MOVE_UNUSED_BUDGET = typing___cast(RecommendationTypeEnum.RecommendationType, 15)
    UNSPECIFIED = typing___cast(RecommendationTypeEnum.RecommendationType, 0)
    UNKNOWN = typing___cast(RecommendationTypeEnum.RecommendationType, 1)
    CAMPAIGN_BUDGET = typing___cast(RecommendationTypeEnum.RecommendationType, 2)
    KEYWORD = typing___cast(RecommendationTypeEnum.RecommendationType, 3)
    TEXT_AD = typing___cast(RecommendationTypeEnum.RecommendationType, 4)
    TARGET_CPA_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 5)
    MAXIMIZE_CONVERSIONS_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 6)
    ENHANCED_CPC_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 7)
    SEARCH_PARTNERS_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 8)
    MAXIMIZE_CLICKS_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 9)
    OPTIMIZE_AD_ROTATION = typing___cast(RecommendationTypeEnum.RecommendationType, 10)
    CALLOUT_EXTENSION = typing___cast(RecommendationTypeEnum.RecommendationType, 11)
    SITELINK_EXTENSION = typing___cast(RecommendationTypeEnum.RecommendationType, 12)
    CALL_EXTENSION = typing___cast(RecommendationTypeEnum.RecommendationType, 13)
    KEYWORD_MATCH_TYPE = typing___cast(RecommendationTypeEnum.RecommendationType, 14)
    MOVE_UNUSED_BUDGET = typing___cast(RecommendationTypeEnum.RecommendationType, 15)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> RecommendationTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
