# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.keyword_match_type_pb2 import (
    KeywordMatchTypeEnum as google___ads___googleads___v2___enums___keyword_match_type_pb2___KeywordMatchTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class KeywordPlanKeyword(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    match_type = ... # type: google___ads___googleads___v2___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchType

    @property
    def keyword_plan_ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def text(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        keyword_plan_ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        text : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        match_type : typing___Optional[google___ads___googleads___v2___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchType] = None,
        cpc_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordPlanKeyword: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_micros",u"id",u"keyword_plan_ad_group",u"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_micros",u"id",u"keyword_plan_ad_group",u"match_type",u"resource_name",u"text"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_micros",b"cpc_bid_micros",u"id",b"id",u"keyword_plan_ad_group",b"keyword_plan_ad_group",u"text",b"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_micros",b"cpc_bid_micros",u"id",b"id",u"keyword_plan_ad_group",b"keyword_plan_ad_group",u"match_type",b"match_type",u"resource_name",b"resource_name",u"text",b"text"]) -> None: ...
