# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.enums.targeting_dimension_pb2 import (
    TargetingDimensionEnum as google___ads___googleads___v1___enums___targeting_dimension_pb2___TargetingDimensionEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class TargetingSetting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def target_restrictions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[TargetRestriction]: ...

    def __init__(self,
        *,
        target_restrictions : typing___Optional[typing___Iterable[TargetRestriction]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TargetingSetting: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"target_restrictions"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"target_restrictions",b"target_restrictions"]) -> None: ...

class TargetRestriction(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    targeting_dimension = ... # type: google___ads___googleads___v1___enums___targeting_dimension_pb2___TargetingDimensionEnum.TargetingDimension

    @property
    def bid_only(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    def __init__(self,
        *,
        targeting_dimension : typing___Optional[google___ads___googleads___v1___enums___targeting_dimension_pb2___TargetingDimensionEnum.TargetingDimension] = None,
        bid_only : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TargetRestriction: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"bid_only"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"bid_only",u"targeting_dimension"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"bid_only",b"bid_only"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"bid_only",b"bid_only",u"targeting_dimension",b"targeting_dimension"]) -> None: ...
