# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class UrlFieldErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class UrlFieldError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> UrlFieldErrorEnum.UrlFieldError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[UrlFieldErrorEnum.UrlFieldError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, UrlFieldErrorEnum.UrlFieldError]]: ...
        UNSPECIFIED = typing___cast(UrlFieldErrorEnum.UrlFieldError, 0)
        UNKNOWN = typing___cast(UrlFieldErrorEnum.UrlFieldError, 1)
        INVALID_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 2)
        INVALID_TAG_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 3)
        MISSING_TRACKING_URL_TEMPLATE_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 4)
        MISSING_PROTOCOL_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 5)
        INVALID_PROTOCOL_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 6)
        MALFORMED_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 7)
        MISSING_HOST_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 8)
        INVALID_TLD_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 9)
        REDUNDANT_NESTED_TRACKING_URL_TEMPLATE_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 10)
        INVALID_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 11)
        INVALID_TAG_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 12)
        REDUNDANT_NESTED_FINAL_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 13)
        MISSING_PROTOCOL_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 14)
        INVALID_PROTOCOL_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 15)
        MALFORMED_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 16)
        MISSING_HOST_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 17)
        INVALID_TLD_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 18)
        INVALID_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 19)
        INVALID_TAG_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 20)
        REDUNDANT_NESTED_FINAL_MOBILE_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 21)
        MISSING_PROTOCOL_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 22)
        INVALID_PROTOCOL_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 23)
        MALFORMED_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 24)
        MISSING_HOST_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 25)
        INVALID_TLD_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 26)
        INVALID_FINAL_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 27)
        INVALID_TAG_IN_FINAL_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 28)
        REDUNDANT_NESTED_FINAL_APP_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 29)
        MULTIPLE_APP_URLS_FOR_OSTYPE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 30)
        INVALID_OSTYPE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 31)
        INVALID_PROTOCOL_FOR_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 32)
        INVALID_PACKAGE_ID_FOR_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 33)
        URL_CUSTOM_PARAMETERS_COUNT_EXCEEDS_LIMIT = typing___cast(UrlFieldErrorEnum.UrlFieldError, 34)
        INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_KEY = typing___cast(UrlFieldErrorEnum.UrlFieldError, 39)
        INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_VALUE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 40)
        INVALID_TAG_IN_URL_CUSTOM_PARAMETER_VALUE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 41)
        REDUNDANT_NESTED_URL_CUSTOM_PARAMETER_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 42)
        MISSING_PROTOCOL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 43)
        INVALID_PROTOCOL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 52)
        INVALID_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 44)
        DESTINATION_URL_DEPRECATED = typing___cast(UrlFieldErrorEnum.UrlFieldError, 45)
        INVALID_TAG_IN_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 46)
        MISSING_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 47)
        DUPLICATE_URL_ID = typing___cast(UrlFieldErrorEnum.UrlFieldError, 48)
        INVALID_URL_ID = typing___cast(UrlFieldErrorEnum.UrlFieldError, 49)
        FINAL_URL_SUFFIX_MALFORMED = typing___cast(UrlFieldErrorEnum.UrlFieldError, 50)
        INVALID_TAG_IN_FINAL_URL_SUFFIX = typing___cast(UrlFieldErrorEnum.UrlFieldError, 51)
        INVALID_TOP_LEVEL_DOMAIN = typing___cast(UrlFieldErrorEnum.UrlFieldError, 53)
        MALFORMED_TOP_LEVEL_DOMAIN = typing___cast(UrlFieldErrorEnum.UrlFieldError, 54)
        MALFORMED_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 55)
        MISSING_HOST = typing___cast(UrlFieldErrorEnum.UrlFieldError, 56)
        NULL_CUSTOM_PARAMETER_VALUE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 57)
    UNSPECIFIED = typing___cast(UrlFieldErrorEnum.UrlFieldError, 0)
    UNKNOWN = typing___cast(UrlFieldErrorEnum.UrlFieldError, 1)
    INVALID_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 2)
    INVALID_TAG_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 3)
    MISSING_TRACKING_URL_TEMPLATE_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 4)
    MISSING_PROTOCOL_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 5)
    INVALID_PROTOCOL_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 6)
    MALFORMED_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 7)
    MISSING_HOST_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 8)
    INVALID_TLD_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 9)
    REDUNDANT_NESTED_TRACKING_URL_TEMPLATE_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 10)
    INVALID_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 11)
    INVALID_TAG_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 12)
    REDUNDANT_NESTED_FINAL_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 13)
    MISSING_PROTOCOL_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 14)
    INVALID_PROTOCOL_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 15)
    MALFORMED_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 16)
    MISSING_HOST_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 17)
    INVALID_TLD_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 18)
    INVALID_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 19)
    INVALID_TAG_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 20)
    REDUNDANT_NESTED_FINAL_MOBILE_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 21)
    MISSING_PROTOCOL_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 22)
    INVALID_PROTOCOL_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 23)
    MALFORMED_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 24)
    MISSING_HOST_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 25)
    INVALID_TLD_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 26)
    INVALID_FINAL_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 27)
    INVALID_TAG_IN_FINAL_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 28)
    REDUNDANT_NESTED_FINAL_APP_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 29)
    MULTIPLE_APP_URLS_FOR_OSTYPE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 30)
    INVALID_OSTYPE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 31)
    INVALID_PROTOCOL_FOR_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 32)
    INVALID_PACKAGE_ID_FOR_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 33)
    URL_CUSTOM_PARAMETERS_COUNT_EXCEEDS_LIMIT = typing___cast(UrlFieldErrorEnum.UrlFieldError, 34)
    INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_KEY = typing___cast(UrlFieldErrorEnum.UrlFieldError, 39)
    INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_VALUE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 40)
    INVALID_TAG_IN_URL_CUSTOM_PARAMETER_VALUE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 41)
    REDUNDANT_NESTED_URL_CUSTOM_PARAMETER_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 42)
    MISSING_PROTOCOL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 43)
    INVALID_PROTOCOL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 52)
    INVALID_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 44)
    DESTINATION_URL_DEPRECATED = typing___cast(UrlFieldErrorEnum.UrlFieldError, 45)
    INVALID_TAG_IN_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 46)
    MISSING_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 47)
    DUPLICATE_URL_ID = typing___cast(UrlFieldErrorEnum.UrlFieldError, 48)
    INVALID_URL_ID = typing___cast(UrlFieldErrorEnum.UrlFieldError, 49)
    FINAL_URL_SUFFIX_MALFORMED = typing___cast(UrlFieldErrorEnum.UrlFieldError, 50)
    INVALID_TAG_IN_FINAL_URL_SUFFIX = typing___cast(UrlFieldErrorEnum.UrlFieldError, 51)
    INVALID_TOP_LEVEL_DOMAIN = typing___cast(UrlFieldErrorEnum.UrlFieldError, 53)
    MALFORMED_TOP_LEVEL_DOMAIN = typing___cast(UrlFieldErrorEnum.UrlFieldError, 54)
    MALFORMED_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 55)
    MISSING_HOST = typing___cast(UrlFieldErrorEnum.UrlFieldError, 56)
    NULL_CUSTOM_PARAMETER_VALUE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 57)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UrlFieldErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
