# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.common.criteria_pb2 import (
    DeviceInfo as google___ads___googleads___v1___common___criteria_pb2___DeviceInfo,
    HotelAdvanceBookingWindowInfo as google___ads___googleads___v1___common___criteria_pb2___HotelAdvanceBookingWindowInfo,
    HotelCheckInDayInfo as google___ads___googleads___v1___common___criteria_pb2___HotelCheckInDayInfo,
    HotelDateSelectionTypeInfo as google___ads___googleads___v1___common___criteria_pb2___HotelDateSelectionTypeInfo,
    HotelLengthOfStayInfo as google___ads___googleads___v1___common___criteria_pb2___HotelLengthOfStayInfo,
    PreferredContentInfo as google___ads___googleads___v1___common___criteria_pb2___PreferredContentInfo,
)

from google.ads.google_ads.v1.proto.enums.bid_modifier_source_pb2 import (
    BidModifierSourceEnum as google___ads___googleads___v1___enums___bid_modifier_source_pb2___BidModifierSourceEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class AdGroupBidModifier(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    bid_modifier_source = ... # type: google___ads___googleads___v1___enums___bid_modifier_source_pb2___BidModifierSourceEnum.BidModifierSource

    @property
    def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def criterion_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def bid_modifier(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def base_ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def hotel_date_selection_type(self) -> google___ads___googleads___v1___common___criteria_pb2___HotelDateSelectionTypeInfo: ...

    @property
    def hotel_advance_booking_window(self) -> google___ads___googleads___v1___common___criteria_pb2___HotelAdvanceBookingWindowInfo: ...

    @property
    def hotel_length_of_stay(self) -> google___ads___googleads___v1___common___criteria_pb2___HotelLengthOfStayInfo: ...

    @property
    def hotel_check_in_day(self) -> google___ads___googleads___v1___common___criteria_pb2___HotelCheckInDayInfo: ...

    @property
    def device(self) -> google___ads___googleads___v1___common___criteria_pb2___DeviceInfo: ...

    @property
    def preferred_content(self) -> google___ads___googleads___v1___common___criteria_pb2___PreferredContentInfo: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        criterion_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        bid_modifier : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        base_ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        bid_modifier_source : typing___Optional[google___ads___googleads___v1___enums___bid_modifier_source_pb2___BidModifierSourceEnum.BidModifierSource] = None,
        hotel_date_selection_type : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___HotelDateSelectionTypeInfo] = None,
        hotel_advance_booking_window : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___HotelAdvanceBookingWindowInfo] = None,
        hotel_length_of_stay : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___HotelLengthOfStayInfo] = None,
        hotel_check_in_day : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___HotelCheckInDayInfo] = None,
        device : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___DeviceInfo] = None,
        preferred_content : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___PreferredContentInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdGroupBidModifier: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group",u"base_ad_group",u"bid_modifier",u"criterion",u"criterion_id",u"device",u"hotel_advance_booking_window",u"hotel_check_in_day",u"hotel_date_selection_type",u"hotel_length_of_stay",u"preferred_content"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",u"base_ad_group",u"bid_modifier",u"bid_modifier_source",u"criterion",u"criterion_id",u"device",u"hotel_advance_booking_window",u"hotel_check_in_day",u"hotel_date_selection_type",u"hotel_length_of_stay",u"preferred_content",u"resource_name"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"base_ad_group",b"base_ad_group",u"bid_modifier",b"bid_modifier",u"criterion",b"criterion",u"criterion_id",b"criterion_id",u"device",b"device",u"hotel_advance_booking_window",b"hotel_advance_booking_window",u"hotel_check_in_day",b"hotel_check_in_day",u"hotel_date_selection_type",b"hotel_date_selection_type",u"hotel_length_of_stay",b"hotel_length_of_stay",u"preferred_content",b"preferred_content"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"base_ad_group",b"base_ad_group",u"bid_modifier",b"bid_modifier",u"bid_modifier_source",b"bid_modifier_source",u"criterion",b"criterion",u"criterion_id",b"criterion_id",u"device",b"device",u"hotel_advance_booking_window",b"hotel_advance_booking_window",u"hotel_check_in_day",b"hotel_check_in_day",u"hotel_date_selection_type",b"hotel_date_selection_type",u"hotel_length_of_stay",b"hotel_length_of_stay",u"preferred_content",b"preferred_content",u"resource_name",b"resource_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"criterion",b"criterion"]) -> typing_extensions___Literal["hotel_date_selection_type","hotel_advance_booking_window","hotel_length_of_stay","hotel_check_in_day","device","preferred_content"]: ...
