# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ReachPlanAgeRangeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ReachPlanAgeRange(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ReachPlanAgeRangeEnum.ReachPlanAgeRange: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ReachPlanAgeRangeEnum.ReachPlanAgeRange]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ReachPlanAgeRangeEnum.ReachPlanAgeRange]]: ...
        UNSPECIFIED = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 0)
        UNKNOWN = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 1)
        AGE_RANGE_18_24 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503001)
        AGE_RANGE_18_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 2)
        AGE_RANGE_18_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 3)
        AGE_RANGE_18_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 4)
        AGE_RANGE_18_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 5)
        AGE_RANGE_18_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 6)
        AGE_RANGE_18_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 7)
        AGE_RANGE_21_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 8)
        AGE_RANGE_25_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503002)
        AGE_RANGE_25_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 9)
        AGE_RANGE_25_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 10)
        AGE_RANGE_25_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 11)
        AGE_RANGE_25_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 12)
        AGE_RANGE_25_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 13)
        AGE_RANGE_35_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503003)
        AGE_RANGE_35_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 14)
        AGE_RANGE_35_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 15)
        AGE_RANGE_35_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 16)
        AGE_RANGE_35_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 17)
        AGE_RANGE_45_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503004)
        AGE_RANGE_45_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 18)
        AGE_RANGE_45_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 19)
        AGE_RANGE_50_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 20)
        AGE_RANGE_55_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503005)
        AGE_RANGE_55_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 21)
        AGE_RANGE_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503006)
    UNSPECIFIED = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 0)
    UNKNOWN = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 1)
    AGE_RANGE_18_24 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503001)
    AGE_RANGE_18_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 2)
    AGE_RANGE_18_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 3)
    AGE_RANGE_18_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 4)
    AGE_RANGE_18_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 5)
    AGE_RANGE_18_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 6)
    AGE_RANGE_18_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 7)
    AGE_RANGE_21_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 8)
    AGE_RANGE_25_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503002)
    AGE_RANGE_25_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 9)
    AGE_RANGE_25_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 10)
    AGE_RANGE_25_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 11)
    AGE_RANGE_25_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 12)
    AGE_RANGE_25_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 13)
    AGE_RANGE_35_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503003)
    AGE_RANGE_35_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 14)
    AGE_RANGE_35_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 15)
    AGE_RANGE_35_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 16)
    AGE_RANGE_35_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 17)
    AGE_RANGE_45_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503004)
    AGE_RANGE_45_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 18)
    AGE_RANGE_45_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 19)
    AGE_RANGE_50_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 20)
    AGE_RANGE_55_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503005)
    AGE_RANGE_55_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 21)
    AGE_RANGE_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503006)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ReachPlanAgeRangeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
