# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class CampaignDraftErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CampaignDraftError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> CampaignDraftErrorEnum.CampaignDraftError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[CampaignDraftErrorEnum.CampaignDraftError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, CampaignDraftErrorEnum.CampaignDraftError]]: ...
        UNSPECIFIED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 0)
        UNKNOWN = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 1)
        DUPLICATE_DRAFT_NAME = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 2)
        INVALID_STATUS_TRANSITION_FROM_REMOVED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 3)
        INVALID_STATUS_TRANSITION_FROM_PROMOTED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 4)
        INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 5)
        CUSTOMER_CANNOT_CREATE_DRAFT = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 6)
        CAMPAIGN_CANNOT_CREATE_DRAFT = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 7)
        INVALID_DRAFT_CHANGE = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 8)
        INVALID_STATUS_TRANSITION = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 9)
        MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 10)
        LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 11)
    UNSPECIFIED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 0)
    UNKNOWN = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 1)
    DUPLICATE_DRAFT_NAME = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 2)
    INVALID_STATUS_TRANSITION_FROM_REMOVED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 3)
    INVALID_STATUS_TRANSITION_FROM_PROMOTED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 4)
    INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 5)
    CUSTOMER_CANNOT_CREATE_DRAFT = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 6)
    CAMPAIGN_CANNOT_CREATE_DRAFT = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 7)
    INVALID_DRAFT_CHANGE = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 8)
    INVALID_STATUS_TRANSITION = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 9)
    MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 10)
    LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY = typing___cast(CampaignDraftErrorEnum.CampaignDraftError, 11)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CampaignDraftErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
