# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.services.google_ads_service_pb2 import (
    MutateOperation as google___ads___googleads___v1___services___google_ads_service_pb2___MutateOperation,
    MutateOperationResponse as google___ads___googleads___v1___services___google_ads_service_pb2___MutateOperationResponse,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.rpc.status_pb2 import (
    Status as google___rpc___status_pb2___Status,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class CreateMutateJobRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CreateMutateJobRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",b"customer_id"]) -> None: ...

class CreateMutateJobResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CreateMutateJobResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class GetMutateJobRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GetMutateJobRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class RunMutateJobRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> RunMutateJobRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class AddMutateJobOperationsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    sequence_token = ... # type: typing___Text

    @property
    def mutate_operations(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v1___services___google_ads_service_pb2___MutateOperation]: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        sequence_token : typing___Optional[typing___Text] = None,
        mutate_operations : typing___Optional[typing___Iterable[google___ads___googleads___v1___services___google_ads_service_pb2___MutateOperation]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AddMutateJobOperationsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"mutate_operations",u"resource_name",u"sequence_token"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"mutate_operations",b"mutate_operations",u"resource_name",b"resource_name",u"sequence_token",b"sequence_token"]) -> None: ...

class AddMutateJobOperationsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    total_operations = ... # type: int
    next_sequence_token = ... # type: typing___Text

    def __init__(self,
        *,
        total_operations : typing___Optional[int] = None,
        next_sequence_token : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AddMutateJobOperationsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"next_sequence_token",u"total_operations"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"next_sequence_token",b"next_sequence_token",u"total_operations",b"total_operations"]) -> None: ...

class ListMutateJobResultsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    page_token = ... # type: typing___Text
    page_size = ... # type: int

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        page_token : typing___Optional[typing___Text] = None,
        page_size : typing___Optional[int] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListMutateJobResultsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"page_size",u"page_token",u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"page_size",b"page_size",u"page_token",b"page_token",u"resource_name",b"resource_name"]) -> None: ...

class ListMutateJobResultsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    next_page_token = ... # type: typing___Text

    @property
    def results(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[MutateJobResult]: ...

    def __init__(self,
        *,
        results : typing___Optional[typing___Iterable[MutateJobResult]] = None,
        next_page_token : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListMutateJobResultsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"next_page_token",u"results"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"next_page_token",b"next_page_token",u"results",b"results"]) -> None: ...

class MutateJobResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operation_index = ... # type: int

    @property
    def mutate_operation_response(self) -> google___ads___googleads___v1___services___google_ads_service_pb2___MutateOperationResponse: ...

    @property
    def status(self) -> google___rpc___status_pb2___Status: ...

    def __init__(self,
        *,
        operation_index : typing___Optional[int] = None,
        mutate_operation_response : typing___Optional[google___ads___googleads___v1___services___google_ads_service_pb2___MutateOperationResponse] = None,
        status : typing___Optional[google___rpc___status_pb2___Status] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateJobResult: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"mutate_operation_response",u"status"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"mutate_operation_response",u"operation_index",u"status"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"mutate_operation_response",b"mutate_operation_response",u"status",b"status"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"mutate_operation_response",b"mutate_operation_response",u"operation_index",b"operation_index",u"status",b"status"]) -> None: ...
