# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class AuthorizationErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AuthorizationError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> AuthorizationErrorEnum.AuthorizationError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[AuthorizationErrorEnum.AuthorizationError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, AuthorizationErrorEnum.AuthorizationError]]: ...
        UNSPECIFIED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 0)
        UNKNOWN = typing___cast(AuthorizationErrorEnum.AuthorizationError, 1)
        USER_PERMISSION_DENIED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 2)
        DEVELOPER_TOKEN_NOT_WHITELISTED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 3)
        DEVELOPER_TOKEN_PROHIBITED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 4)
        PROJECT_DISABLED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 5)
        AUTHORIZATION_ERROR = typing___cast(AuthorizationErrorEnum.AuthorizationError, 6)
        ACTION_NOT_PERMITTED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 7)
        INCOMPLETE_SIGNUP = typing___cast(AuthorizationErrorEnum.AuthorizationError, 8)
        CUSTOMER_NOT_ENABLED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 24)
        MISSING_TOS = typing___cast(AuthorizationErrorEnum.AuthorizationError, 9)
        DEVELOPER_TOKEN_NOT_APPROVED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 10)
    UNSPECIFIED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 0)
    UNKNOWN = typing___cast(AuthorizationErrorEnum.AuthorizationError, 1)
    USER_PERMISSION_DENIED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 2)
    DEVELOPER_TOKEN_NOT_WHITELISTED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 3)
    DEVELOPER_TOKEN_PROHIBITED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 4)
    PROJECT_DISABLED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 5)
    AUTHORIZATION_ERROR = typing___cast(AuthorizationErrorEnum.AuthorizationError, 6)
    ACTION_NOT_PERMITTED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 7)
    INCOMPLETE_SIGNUP = typing___cast(AuthorizationErrorEnum.AuthorizationError, 8)
    CUSTOMER_NOT_ENABLED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 24)
    MISSING_TOS = typing___cast(AuthorizationErrorEnum.AuthorizationError, 9)
    DEVELOPER_TOKEN_NOT_APPROVED = typing___cast(AuthorizationErrorEnum.AuthorizationError, 10)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AuthorizationErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
