# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ExtensionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ExtensionType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ExtensionTypeEnum.ExtensionType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ExtensionTypeEnum.ExtensionType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ExtensionTypeEnum.ExtensionType]]: ...
        UNSPECIFIED = typing___cast(ExtensionTypeEnum.ExtensionType, 0)
        UNKNOWN = typing___cast(ExtensionTypeEnum.ExtensionType, 1)
        NONE = typing___cast(ExtensionTypeEnum.ExtensionType, 2)
        APP = typing___cast(ExtensionTypeEnum.ExtensionType, 3)
        CALL = typing___cast(ExtensionTypeEnum.ExtensionType, 4)
        CALLOUT = typing___cast(ExtensionTypeEnum.ExtensionType, 5)
        MESSAGE = typing___cast(ExtensionTypeEnum.ExtensionType, 6)
        PRICE = typing___cast(ExtensionTypeEnum.ExtensionType, 7)
        PROMOTION = typing___cast(ExtensionTypeEnum.ExtensionType, 8)
        REVIEW = typing___cast(ExtensionTypeEnum.ExtensionType, 9)
        SITELINK = typing___cast(ExtensionTypeEnum.ExtensionType, 10)
        STRUCTURED_SNIPPET = typing___cast(ExtensionTypeEnum.ExtensionType, 11)
        LOCATION = typing___cast(ExtensionTypeEnum.ExtensionType, 12)
        AFFILIATE_LOCATION = typing___cast(ExtensionTypeEnum.ExtensionType, 13)
    UNSPECIFIED = typing___cast(ExtensionTypeEnum.ExtensionType, 0)
    UNKNOWN = typing___cast(ExtensionTypeEnum.ExtensionType, 1)
    NONE = typing___cast(ExtensionTypeEnum.ExtensionType, 2)
    APP = typing___cast(ExtensionTypeEnum.ExtensionType, 3)
    CALL = typing___cast(ExtensionTypeEnum.ExtensionType, 4)
    CALLOUT = typing___cast(ExtensionTypeEnum.ExtensionType, 5)
    MESSAGE = typing___cast(ExtensionTypeEnum.ExtensionType, 6)
    PRICE = typing___cast(ExtensionTypeEnum.ExtensionType, 7)
    PROMOTION = typing___cast(ExtensionTypeEnum.ExtensionType, 8)
    REVIEW = typing___cast(ExtensionTypeEnum.ExtensionType, 9)
    SITELINK = typing___cast(ExtensionTypeEnum.ExtensionType, 10)
    STRUCTURED_SNIPPET = typing___cast(ExtensionTypeEnum.ExtensionType, 11)
    LOCATION = typing___cast(ExtensionTypeEnum.ExtensionType, 12)
    AFFILIATE_LOCATION = typing___cast(ExtensionTypeEnum.ExtensionType, 13)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ExtensionTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
