# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class PromotionExtensionOccasionEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class PromotionExtensionOccasion(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> PromotionExtensionOccasionEnum.PromotionExtensionOccasion: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[PromotionExtensionOccasionEnum.PromotionExtensionOccasion]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, PromotionExtensionOccasionEnum.PromotionExtensionOccasion]]: ...
        UNSPECIFIED = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 0)
        UNKNOWN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 1)
        NEW_YEARS = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 2)
        CHINESE_NEW_YEAR = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 3)
        VALENTINES_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 4)
        EASTER = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 5)
        MOTHERS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 6)
        FATHERS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 7)
        LABOR_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 8)
        BACK_TO_SCHOOL = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 9)
        HALLOWEEN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 10)
        BLACK_FRIDAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 11)
        CYBER_MONDAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 12)
        CHRISTMAS = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 13)
        BOXING_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 14)
        INDEPENDENCE_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 15)
        NATIONAL_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 16)
        END_OF_SEASON = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 17)
        WINTER_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 18)
        SUMMER_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 19)
        FALL_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 20)
        SPRING_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 21)
        RAMADAN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 22)
        EID_AL_FITR = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 23)
        EID_AL_ADHA = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 24)
        SINGLES_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 25)
        WOMENS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 26)
        HOLI = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 27)
        PARENTS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 28)
        ST_NICHOLAS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 29)
        CARNIVAL = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 30)
        EPIPHANY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 31)
        ROSH_HASHANAH = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 32)
        PASSOVER = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 33)
        HANUKKAH = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 34)
        DIWALI = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 35)
        NAVRATRI = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 36)
        SONGKRAN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 37)
        YEAR_END_GIFT = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 38)
    UNSPECIFIED = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 0)
    UNKNOWN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 1)
    NEW_YEARS = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 2)
    CHINESE_NEW_YEAR = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 3)
    VALENTINES_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 4)
    EASTER = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 5)
    MOTHERS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 6)
    FATHERS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 7)
    LABOR_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 8)
    BACK_TO_SCHOOL = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 9)
    HALLOWEEN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 10)
    BLACK_FRIDAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 11)
    CYBER_MONDAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 12)
    CHRISTMAS = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 13)
    BOXING_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 14)
    INDEPENDENCE_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 15)
    NATIONAL_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 16)
    END_OF_SEASON = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 17)
    WINTER_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 18)
    SUMMER_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 19)
    FALL_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 20)
    SPRING_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 21)
    RAMADAN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 22)
    EID_AL_FITR = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 23)
    EID_AL_ADHA = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 24)
    SINGLES_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 25)
    WOMENS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 26)
    HOLI = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 27)
    PARENTS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 28)
    ST_NICHOLAS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 29)
    CARNIVAL = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 30)
    EPIPHANY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 31)
    ROSH_HASHANAH = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 32)
    PASSOVER = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 33)
    HANUKKAH = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 34)
    DIWALI = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 35)
    NAVRATRI = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 36)
    SONGKRAN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 37)
    YEAR_END_GIFT = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 38)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PromotionExtensionOccasionEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
